@@ -16,7 +16,7 @@ from strategy_api.tm_api.api.websocket.websocket_client import WebsocketClient
 from strategy_api.tm_api.base import BaseGateway
 from strategy_api.tm_api.object import TickData, BarData, Interval, OrderRequest, OrderData, Direction, OrderType, \
     Offset, Status, CancelRequest, HistoryRequest, PositionSide, DataType, Exchange, Product, AskData, BidData, \
-    DepthData, TdMode
+    DepthData, TdMode, PositionData
 
 # http 基础地址
 from strategy_api.tm_api.tools import get_order_type, symbol_deal
@@ -271,6 +271,12 @@ class BinanceFutureInverseGateway(BaseGateway):
     def send_order(self, req: OrderRequest, orderid: str):
         return self.rest_api.send_order(req, orderid)
 
+    def query_position(self, symbol: str) -> List[PositionData]:
+        """query position"""
+        new_symbol = symbol_deal(symbol, self.exchange)
+        self.symbolMap[new_symbol] = symbol
+        return self.rest_api.query_position(new_symbol)
+
     # 撤销订单
     def cancel_order(self, orderid: str, symbol: str) -> None:
         new_symbol = symbol_deal(symbol, self.exchange)
@@ -333,7 +339,8 @@ class BinanceFutureInverseGateway(BaseGateway):
 
     def query_symbol(self, quote_symbol: str, s_type: str = "") -> list:
         new_quote_symbol = quote_symbol + "_PERP"
-        return [i.replace(new_quote_symbol.upper(), "-" + quote_symbol.upper()) for i in self.SYMBOL_SET if i.endswith(new_quote_symbol.upper())]
+        return [i.replace(new_quote_symbol.upper(), "-" + quote_symbol.upper()) for i in self.SYMBOL_SET if
+                i.endswith(new_quote_symbol.upper())]
 
     # 订阅数据
     def subscribe(self, symbol: str, data_type: DataType, interval: Interval = None) -> None:
@@ -661,6 +668,46 @@ class BinanceInverseRestApi(RestClient):
         history = list(reversed(history))
         return history
 
+    def query_position(self, symbol: str) -> List[PositionData]:
+        """query position"""
+        pos_l = []
+        params = {
+            "pair": symbol.replace("_PERP", "")
+        }
+        resp: Response = self.request(
+            method="GET",
+            path="/dapi/v1/positionRisk",
+            data={"security": Security.SIGNED},
+            params=params
+        )
+        if resp.status_code // 100 != 2:
+            msg: str = f"查询仓位数据是比, status code：{resp.status_code}，msg：{resp.text}"
+            print(msg)
+        else:
+            data: dict = resp.json()
+
+            for d in data:
+                if "PERP" in d['symbol']:
+                    position: PositionData = PositionData(
+                        symbol=self.gateway.symbolMap[symbol],
+                        exchange=Exchange.BINANCE,
+                        volume=float(d["positionAmt"]),
+                        price=float(d["entryPrice"]),
+                        mark_price=float(d['markPrice']),
+                        liquidation_price=float(d['liquidationPrice']),
+                        leverage=int(d['leverage']),
+                        pnl=float(d["unRealizedProfit"]),
+                    )
+
+                    # if position.volume:
+                    volume = d["positionAmt"]
+                    if '.' in volume:
+                        position.volume = float(d["positionAmt"])
+                    else:
+                        position.volume = int(d["positionAmt"])
+                    pos_l.append(position)
+            return pos_l
+
     def query_depth(self, symbol: str, limit: int, depth_data: DepthData) -> DepthData:
         params: dict = {
             "symbol": symbol,
@@ -669,7 +716,7 @@ class BinanceInverseRestApi(RestClient):
 
         resp: Response = self.request(
             "GET",
-            "/api/v3/depth",
+            "/dapi/v1/depth",
             data={"security": Security.NONE},
             params=params
         )
