@@ -16,7 +16,7 @@ from strategy_api.tm_api.api.websocket.websocket_client import WebsocketClient
 from strategy_api.tm_api.base import BaseGateway
 from strategy_api.tm_api.object import TickData, BarData, Interval, OrderRequest, OrderData, Direction, OrderType, \
     Offset, Status, CancelRequest, HistoryRequest, PositionSide, DataType, Product, Exchange, DepthData, BidData, \
-    AskData, TdMode
+    AskData, TdMode, PositionData
 
 # http 基础地址
 from strategy_api.tm_api.tools import get_order_type, symbol_deal
@@ -329,8 +329,15 @@ class BinanceFutureUsdtGateway(BaseGateway):
             return depth_data
         return self.rest_api.query_depth(new_symbol, limit, depth_data)
 
+    def query_position(self, symbol: str) -> List[PositionData]:
+        """query position"""
+        new_symbol = symbol_deal(symbol, self.exchange)
+        self.symbolMap[new_symbol] = symbol
+        return self.rest_api.query_position(new_symbol)
+
     def query_symbol(self, quote_symbol: str, s_type: str = "") -> list:
-        return [i.replace(quote_symbol.upper(), "-" + quote_symbol.upper()) for i in self.SYMBOL_SET if i.endswith(quote_symbol.upper())]
+        return [i.replace(quote_symbol.upper(), "-" + quote_symbol.upper()) for i in self.SYMBOL_SET if
+                i.endswith(quote_symbol.upper())]
 
     # 订阅数据
     def subscribe(self, symbol: str, data_type: DataType, interval: Interval = None) -> None:
@@ -653,6 +660,45 @@ class BinanceUsdtRestApi(RestClient):
 
         return history
 
+    def query_position(self, symbol: str) -> List[PositionData]:
+        """query position"""
+        pos_l = []
+        params = {
+            "symbol": symbol
+        }
+        resp: Response = self.request(
+            method="GET",
+            path="/fapi/v2/positionRisk",
+            data={"security": Security.SIGNED},
+            params=params
+        )
+        if resp.status_code // 100 != 2:
+            msg: str = f"查询仓位数据是比, status code：{resp.status_code}，msg：{resp.text}"
+            print(msg)
+        else:
+            data: dict = resp.json()
+
+            for d in data:
+                position: PositionData = PositionData(
+                    symbol=self.gateway.symbolMap[symbol],
+                    exchange=Exchange.BINANCE,
+                    volume=float(d["positionAmt"]),
+                    price=float(d["entryPrice"]),
+                    mark_price=float(d['markPrice']),
+                    liquidation_price=float(d['liquidationPrice']),
+                    leverage=int(d['leverage']),
+                    pnl=float(d["unRealizedProfit"]),
+                )
+
+                # if position.volume:
+                volume = d["positionAmt"]
+                if '.' in volume:
+                    position.volume = float(d["positionAmt"])
+                else:
+                    position.volume = int(d["positionAmt"])
+                pos_l.append(position)
+            return pos_l
+
     def query_depth(self, symbol: str, limit: int, depth_data: DepthData) -> DepthData:
         params: dict = {
             "symbol": symbol,
@@ -661,7 +707,7 @@ class BinanceUsdtRestApi(RestClient):
 
         resp: Response = self.request(
             "GET",
-            "/api/v3/depth",
+            "/fapi/v1/depth",
             data={"security": Security.NONE},
             params=params
         )
