@@ -23,7 +23,7 @@ from strategy_api.tm_api.api.websocket.websocket_client import WebsocketClient
 from strategy_api.tm_api.base import BaseGateway
 from strategy_api.tm_api.object import Status, OrderType, Direction, Interval, TickData, BarData, Product, ContractData, \
     Exchange, DataType, HistoryRequest, PositionSide, OrderRequest, Offset, OrderData, CancelRequest, TdMode, \
-    WithDrawData, Dest, Chain, TransferType, TransferRequest, DepthData, BidData, AskData
+    WithDrawData, Dest, Chain, TransferType, TransferRequest, DepthData, BidData, AskData, PositionData
 from strategy_api.tm_api.tools import get_order_type, symbol_deal
 
 REST_HOST: str = "https://www.okx.com"
@@ -212,6 +212,18 @@ class OkexGateway(BaseGateway):
         )
         return self.rest_api.query_history(req)
 
+    def query_position(self, symbol: str) -> List[PositionData]:
+        """query position"""
+        new_symbol = symbol_deal(symbol, self.exchange)
+        if "MARGIN" in symbol:
+            s_type = "MARGIN"
+        elif "PERP" in symbol or "SWAP" in new_symbol:
+            s_type = "SWAP"
+        else:
+            return []
+        self.symbolMap[new_symbol] = symbol
+        return self.rest_api.query_position(new_symbol, s_type)
+
     def query_depth(self, symbol: str, limit: int) -> DepthData:
         new_symbol = symbol_deal(symbol, self.exchange)
         self.symbolMap[new_symbol] = symbol
@@ -643,6 +655,41 @@ class OkexRestApi(RestClient):
         history: List[BarData] = [buf[i] for i in index]
         return history
 
+    def query_position(self, symbol: str, s_type: str) -> List[PositionData]:
+        """query position"""
+        pos_l = []
+
+        params = {
+            "instType": s_type,
+            "instId": symbol
+        }
+        resp: Response = self.request(
+            method="GET",
+            path="/api/v5/account/positions",
+            params=params
+        )
+        if resp.status_code // 100 != 2:
+            msg: str = f"查询仓位数据是比, status code：{resp.status_code}，msg：{resp.text}"
+            print(msg)
+        else:
+            data: dict = resp.json()
+            for d in data['data']:
+                position: PositionData = PositionData(
+                    symbol=self.gateway.symbolMap[symbol],
+                    exchange=Exchange.OKEX,
+                    volume=float(d["pos"]),
+                    price=float(d["avgPx"]),
+                    mark_price=float(d['markPx']),
+                    liquidation_price=None,
+                    leverage=int(d['lever']),
+                    pnl=float(d["upl"]),
+                )
+                if d['liqPx']:
+                    position.liquidation_price = float(d['liqPx'])
+                pos_l.append(position)
+                break
+            return pos_l
+
     def query_depth(self, symbol: str, limit: int, depth_data: DepthData) -> DepthData:
         params: dict = {
             "instId": symbol,
