@@ -4,7 +4,7 @@ from typing import Dict, Any, List
 from strategy_api.event.engine import EVENT_TICK, EVENT_BAR, EVENT_ORDER
 from strategy_api.event.engine import EventEngine, Event
 from strategy_api.tm_api.object import OrderData, BarData, TickData, Interval, OrderRequest, HistoryRequest, \
-    PositionSide, DataType, Exchange, Product, TdMode, Dest, Chain, TransferType, DepthData
+    PositionSide, DataType, Exchange, Product, TdMode, Dest, Chain, TransferType, DepthData, PositionData
 
 
 class BaseGateway(ABC):
@@ -105,6 +105,9 @@ class BaseGateway(ABC):
     def query_history(self, symbol: str, interval: Interval, hour: int = 0, minutes: int = 0, end_time: datetime = None) -> List[BarData]:
         pass
 
+    def query_position(self, symbol: str) -> List[PositionData]:
+        pass
+
     def subscribe(self, symbol: str, data_type: DataType, interval: Interval = None) -> None:
         pass
 
