@@ -183,12 +183,14 @@ class AskData:
     ask_price: float = 0
     ask_volume: float = 0
 
+
 @dataclass
 class DepthData:
     symbol: str
     bid_data: List[BidData]
     ask_data: List[AskData]
 
+
 # order 数据：当前挂单
 @dataclass
 class OrderData:
@@ -332,3 +334,16 @@ class ContractData:
     size: float  # 合约乘数
     pricetick: float  # 下单价格精度
     min_volume: float = float(1)  # 最小下单数量
+
+
+@dataclass
+class PositionData:
+    exchange: Exchange  # 交易所
+    symbol: str  # 交易对
+    volume: float = 0  # 头寸数量, 符号代表多空方向, 正数为多, 负数为空
+    price: float = 0  # 开仓均价
+    mark_price: float = 0  # 当前标记价格
+    liquidation_price: float = 0  # 参考强平价格
+    leverage: int = 1  # 当前杠杆倍数
+    # marginType: TdMode = TdMode.CROSS  # 逐仓模式或全仓模式
+    pnl: float = 0  # 持仓未实现盈亏
