@@ -10,11 +10,19 @@ def symbol_deal(symbol: str, exchange: Exchange) -> str:
     if exchange == Exchange.BINANCE:
         if "PERP" in l:
             return l[0] + l[1] + "_PERP"
+        elif "SPOT" in l:
+            return l[0] + l[1]
+        elif "MARGIN" in l:
+            return l[0] + l[1]
         else:
             return l[0] + l[1]
     elif exchange == Exchange.OKEX:
         if "PERP" in l:
             return symbol.replace("PERP", "SWAP")
+        elif "SPOT" in l:
+            return l[0] + '-' + l[1]
+        elif "MARGIN" in l:
+            return l[0] + '-' + l[1]
         else:
             return symbol + "-SWAP"
     else:
